<nav class="navbar navbar-expand-sm bg-body-tertiary">
  <div class="container-sm">
    <a class="navbar-brand" href="{{url_for('index')}}">Home</a>
  <div class="collapse navbar-collapse" id="navbarSupportedContent">
    <ul class="navbar-nav me-auto mb-1 mb-sm-0">

      <li class="nav-item">
        <a class="nav-link active" aria-current="page" href="{{url_for('masina')}}">Hyundai</a>
      </li>

      <li class="nav-item">
        <a class="nav-link active" aria-current="page" href="{{url_for('cheltuieli')}}">Chelt</a>
      </li>

    </ul>
  </div>
  </div>
</nav>